@@ -1,11 +1,12 @@
 "track" <- function(txy, id=gl(1, nrow(txy)), subset)
 {
-    ## Purpose: Calculate per deployment, per point-pair travel summary.
+    ## Value: A data frame with a per point-pair travel summary.
     ## --------------------------------------------------------------------
-    ## Arguments: txy=data.frame whose first col represents chron time,
-    ## second and third col represent lon and lat, respectively,
-    ## id=a factor dividing the data into sections, subset=logical expression
-    ## indicating which rows should be analyzed (optional).
+    ## Arguments: txy=data.frame whose first col represents POSIXct
+    ## date/time, second and third col represent lon and lat,
+    ## respectively, id=a factor dividing the data into sections,
+    ## subset=logical expression indicating which rows should be analyzed
+    ## (optional).
     ## --------------------------------------------------------------------
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
@@ -22,11 +23,9 @@
     locs <- txy[r, ]
     splitlocs <- split(locs, id[r])
     ## function to apply to each subset
-    perid <- function(x) {
-        distSpeed(x[-nrow(x), ], x[-1, ])
-    }
+    perid <- function(x) distSpeed(x[-nrow(x), ], x[-1, ])
     track <- lapply(splitlocs, perid)
     tracktab <- do.call("rbind", track)
-    data.frame(id=rep(as.numeric(names(track)), sapply(track, nrow)),
-               tracktab)
+    id <- rep(as.numeric(names(track)), sapply(track, nrow))
+    data.frame(id=id, tracktab)
 }
